@@ -17,9 +17,9 @@ my  $xyz_def = Graphics::Toolkit::Color::Space->new( alias => 'CIEXYZ',
 sub from_rgb {
     my ($rgb) = shift;
     my @rgb = map {apply_d65( $_ )} @$rgb;
-    return mult_matrix3([[0.433949941, 0.37620977,  0.18984029], # conversion + normalisation
-                         [0.2126729,   0.7151522,   0.0721750],
-                         [0.017756583, 0.109467961, 0.872775456]], @rgb);
+    return [ mult_matrix3([[0.433949941, 0.37620977,  0.18984029], # conversion + normalisation
+                          [0.2126729,   0.7151522,   0.0721750],
+                          [0.017756583, 0.109467961, 0.872775456]], @rgb) ];
 
 
 }
@@ -29,7 +29,7 @@ sub to_rgb {
     my @rgb = mult_matrix3([[  3.07996,   -1.53714 , -0.542816 ],
                             [ -0.921259 ,  1.87601 ,  0.0452475],
                             [  0.0528874, -0.204026,  1.15114  ]], @$xyz);
-    return map { remove_d65($_) } @rgb;
+    return [ map { remove_d65($_) } @rgb ];
 }
 
 $xyz_def;
